@@ -8,6 +8,8 @@ from scalecast.Forecaster import (
     mape,
     mae,
     r2,
+    _return_na_if_len_zero,
+    _convert_m,
 )
 
 class SeriesTransformer:
@@ -15,8 +17,8 @@ class SeriesTransformer:
         """ Initiates the object.
 
         Args:
-            f (Forecaster): the Forecaster object that will receive each transformation/revert
-            deepcopy (bool): default True. whether to store a deepcopy of the Forecaster object in the SeriesTransformer object
+            f (Forecaster): The Forecaster object that will receive each transformation/revert.
+            deepcopy (bool): Default True. Whether to store a deepcopy of the Forecaster object in the SeriesTransformer object.
         """
         self.f = f.__deepcopy__() if deepcopy else f
 
@@ -27,15 +29,15 @@ class SeriesTransformer:
         return self.__repr__()
 
     def Transform(self, transform_func, **kwargs):
-        """ transforms the y attribute in the Forecaster object.
+        """ Transforms the y attribute in the Forecaster object.
         
         Args:
-            transform_func (function): the function that will be used to make the transformation.
-                if using a user function, first argument must be the array to transform.
-            **kwargs: passed to the function passed to transform_func.
+            transform_func (function): The function that will be used to make the transformation.
+                If using a user function, first argument must be the array to transform.
+            **kwargs: Passed to the function passed to transform_func.
 
         Returns:
-            (Forecaster): a Forecaster object with the transformed attributes.
+            (Forecaster): A Forecaster object with the transformed attributes.
 
         >>> import math
         >>> from scalecast.Forecaster import Forecaster
@@ -51,16 +53,16 @@ class SeriesTransformer:
         return self.f
 
     def Revert(self, revert_func, full=True, exclude_models = [], **kwargs):
-        """ reverts the y attribute in the Forecaster object, along with all model results.
+        """ Reverts the y attribute in the Forecaster object, along with all model results.
 
         Args:
-            revert_func (function): the function that will be used to revert the values.
-                if using a user function, first argument must be the array to transform.
-            full (bool): whether to revert all attributes, or just the level attributes.
-                if False, all non-level results will remain unchanged.
-            exclude_models (list-like): models to not revert. this is useful if you are transforming
+            revert_func (function): The function that will be used to revert the values.
+                If using a user function, first argument must be the array to transform.
+            full (bool): Whether to revert all attributes, or just the level attributes.
+                If False, all non-level results will remain unchanged.
+            exclude_models (list-like): Models to not revert. This is useful if you are transforming
                 and reverting an object over and over.
-            **kwargs: passed to the function passed to revert_func.
+            **kwargs: Passed to the function passed to revert_func.
 
         Returns:
             (Forecaster): a Forecaster object with the reverted attributes.
@@ -99,10 +101,10 @@ class SeriesTransformer:
                 pred = h[preds]
                 act = self.f.levely[-len(pred) :]
                 if i == 0:
-                    h["LevelTestSetRMSE"] = rmse(act, pred)
-                    h["LevelTestSetMAPE"] = mape(act, pred)
-                    h["LevelTestSetMAE"] = mae(act, pred)
-                    h["LevelTestSetR2"] = r2(act, pred)
+                    h["LevelTestSetRMSE"] = _return_na_if_len_zero(act, pred, rmse)
+                    h["LevelTestSetMAPE"] = _return_na_if_len_zero(act, pred, mape)
+                    h["LevelTestSetMAE"] = _return_na_if_len_zero(act, pred, mae)
+                    h["LevelTestSetR2"] = _return_na_if_len_zero(act, pred, r2)
                 elif i == 1:
                     h["LevelInSampleRMSE"] = rmse(act, pred)
                     h["LevelInSampleMAPE"] = mape(act, pred)
@@ -115,25 +117,21 @@ class SeriesTransformer:
                     "TestSetPredictions",
                     "TestSetUpperCI",
                     "TestSetLowerCI",
-                    "CIPlusMinus",
                     "UpperCI",
                     "LowerCI",
                     "TestSetActuals",
                     "FittedVals",
                 ):
-                    try:
-                        h[k] = pd.Series(revert_func(h[k], **kwargs)).fillna(method='ffill').to_list()
-                    except TypeError:
-                        h[k] = revert_func([h[k]], **kwargs)[0]
+                    h[k] = pd.Series(revert_func(h[k], **kwargs)).fillna(method='ffill').to_list()
 
                 for i, preds in enumerate(("TestSetPredictions","FittedVals")):
                     pred = h[preds]
                     act = self.f.levely[-len(pred) :]
                     if i == 0:
-                        h["TestSetRMSE"] = rmse(act, pred)
-                        h["TestSetMAPE"] = mape(act, pred)
-                        h["TestSetMAE"] = mae(act, pred)
-                        h["TestSetR2"] = r2(act, pred)
+                        h["TestSetRMSE"] = _return_na_if_len_zero(act, pred, rmse)
+                        h["TestSetMAPE"] = _return_na_if_len_zero(act, pred, mape)
+                        h["TestSetMAE"] = _return_na_if_len_zero(act, pred, mae)
+                        h["TestSetR2"] = _return_na_if_len_zero(act, pred, r2)
                     elif i == 1:
                         h["InSampleRMSE"] = rmse(act, pred)
                         h["InSampleMAPE"] = mape(act, pred)
@@ -151,29 +149,29 @@ class SeriesTransformer:
             fit_intercept=True,
             train_only=False,
         ):
-        """ detrends the series using an OLS estimator.
-        only call this once if you want to revert the series later.
-        the passed Forecaster object must have future dates or be initiated with `require_future_dates=False`.
-        make sure the test length has already been set as well.
-        if the test length changes between the time the transformation is called
+        """ Detrends the series using an OLS estimator.
+        Only call this once if you want to revert the series later.
+        The passed Forecaster object must have future dates or be initiated with `require_future_dates=False`.
+        Make sure the test length has already been set as well.
+        If the test length changes between the time the transformation is called
         and when models are called, you will get this error when reverting: 
         ValueError: All arrays must be of the same length.
-        the ols model from statsmodels will be stored in the detrend_model attribute.
+        The ols model from statsmodels will be stored in the detrend_model attribute.
 
         Args:
-            poly_order (int): default 1. the polynomial order to use.
-            ln_trend (bool): default False. whether to use a natural logarithmic trend.
-            seasonal_lags (int): default 0. the number of seasonal lags to use in the estimation.
-            m (int or str): default 'auto'. the number of observations that counts one seasonal step.
-                ignored when seasonal_lags = 0.
-                when 'auto', uses the M4 competition values:
+            poly_order (int): Default 1. The polynomial order to use.
+            ln_trend (bool): Default False. Whether to use a natural logarithmic trend.
+            seasonal_lags (int): Default 0. The number of seasonal lags to use in the estimation.
+            m (int or str): Default 'auto'. The number of observations that counts one seasonal step.
+                Ignored when seasonal_lags = 0.
+                When 'auto', uses the M4 competition values:
                 for Hourly: 24, Monthly: 12, Quarterly: 4. everything else gets 1 (no seasonality assumed)
                 so pass your own values for other frequencies.
-            fit_intercept (bool): default True. whether to fit an intercept in the model.
-            train_only (bool): default False. whether to fit the OLS model on the training set only.
+            fit_intercept (bool): Default True. Whether to fit an intercept in the model.
+            train_only (bool): Default False. Whether to fit the OLS model on the training set only.
 
         Returns:
-            (Forecaster): a Forecaster object with the transformed attributes.
+            (Forecaster): A Forecaster object with the transformed attributes.
 
         >>> from scalecast.Forecaster import Forecaster
         >>> from scalecast.SeriesTransformer import SeriesTransformer
@@ -182,7 +180,6 @@ class SeriesTransformer:
         >>> f = transformer.DetrendTransform(ln_trend=True)
         """
         import statsmodels.api as sm 
-        from scalecast.util import _convert_m
         
         self.detrend_origy = self.f.y.copy()
         self.detrend_origlevely = self.f.levely.copy()
@@ -249,19 +246,19 @@ class SeriesTransformer:
         return self.f
 
     def DetrendRevert(self, exclude_models = []):
-        """ reverts the y attribute in the Forecaster object, along with all model results.
-        assumes a detrend transformation has already been called and uses all model information
+        """ Reverts the y attribute in the Forecaster object, along with all model results.
+        Assumes a detrend transformation has already been called and uses all model information
         already recorded from that transformation to revert.
-        if the test length changes in the Forecaster object between the time the transformation is called
+        If the test length changes in the Forecaster object between the time the transformation is called
         and when models are called, you will get this error when reverting: 
         ValueError: All arrays must be of the same length.
 
         Args:
-            exclude_models (list-like): models to not revert. this is useful if you are transforming
-                and reverting an object over and over.
+            exclude_models (list-like): Models to not revert. This is useful if you are transforming
+                and reverting an object multiple times.
         
         Returns:
-            (Forecaster): a Forecaster object with the reverted attributes.
+            (Forecaster): A Forecaster object with the reverted attributes.
 
         >>> from scalecast.Forecaster import Forecaster
         >>> from scalecast.SeriesTransformer import SeriesTransformer
@@ -314,10 +311,10 @@ class SeriesTransformer:
         return self.Revert(lambda x: x)  # call here to assign correct test-set metrics
         
     def LogTransform(self):
-        """ transforms the y attribute in the Forecaster object using a natural log transformation.
+        """ Transforms the y attribute in the Forecaster object using a natural log transformation.
 
         Returns:
-            (Forecaster): a Forecaster object with the transformed attributes.
+            (Forecaster): A Forecaster object with the transformed attributes.
 
         >>> from scalecast.Forecaster import Forecaster
         >>> from scalecast.SeriesTransformer import SeriesTransformer
@@ -328,15 +325,15 @@ class SeriesTransformer:
         return self.Transform(np.log)
 
     def LogRevert(self, **kwargs):
-        """ reverts the y attribute in the Forecaster object, along with all model results.
-        assumes a natural log transformation has already been called.
+        """ Reverts the y attribute in the Forecaster object, along with all model results.
+        Assumes a natural log transformation has already been called.
 
         Args:
-            **kwargs: passed to Transformer.Revert() - 
+            **kwargs: Passed to Transformer.Revert() - 
                 args `full` and `exclude_models` accepted here.
 
         Returns:
-            (Forecaster): a Forecaster object with the reverted attributes.
+            (Forecaster): A Forecaster object with the reverted attributes.
 
         >>> from scalecast.Forecaster import Forecaster
         >>> from scalecast.SeriesTransformer import SeriesTransformer
@@ -348,10 +345,10 @@ class SeriesTransformer:
         return self.Revert(np.exp, **kwargs)
 
     def SqrtTransform(self):
-        """ transforms the y attribute in the Forecaster object using a square-root transformation.
+        """ Transforms the y attribute in the Forecaster object using a square-root transformation.
 
         Returns:
-            (Forecaster): a Forecaster object with the transformed attributes.
+            (Forecaster): A Forecaster object with the transformed attributes.
 
         >>> from scalecast.Forecaster import Forecaster
         >>> from scalecast.SeriesTransformer import SeriesTransformer
@@ -362,15 +359,15 @@ class SeriesTransformer:
         return self.Transform(np.sqrt)
 
     def SqrtRevert(self, **kwargs):
-        """ reverts the y attribute in the Forecaster object, along with all model results.
-        assumes a square-root transformation has already been called.
+        """ Reverts the y attribute in the Forecaster object, along with all model results.
+        Assumes a square-root transformation has already been called.
 
         Args:
-            **kwargs: passed to Transformer.Revert() - 
+            **kwargs: Passed to Transformer.Revert() - 
                 args `full` and `exclude_models` accepted here.
 
         Returns:
-            (Forecaster): a Forecaster object with the reverted attributes.
+            (Forecaster): A Forecaster object with the reverted attributes.
 
         >>> from scalecast.Forecaster import Forecaster
         >>> from scalecast.SeriesTransformer import SeriesTransformer
@@ -382,14 +379,14 @@ class SeriesTransformer:
         return self.Revert(np.square, **kwargs)
 
     def ScaleTransform(self,train_only=False):
-        """ transforms the y attribute in the Forecaster object using a scale transformation.
-        scale defined as (array[i] - array.mean()) / array.std().
+        """ Transforms the y attribute in the Forecaster object using a scale transformation.
+        Scale defined as (array[i] - array.mean()) / array.std().
 
         Args:
-            train_only (bool): default False.
-                whether to fit the scale transformer on the training set only.
+            train_only (bool): Default False.
+                Whether to fit the scale transformer on the training set only.
         Returns:
-            (Forecaster): a Forecaster object with the transformed attributes.
+            (Forecaster): A Forecaster object with the transformed attributes.
 
         >>> from scalecast.Forecaster import Forecaster
         >>> from scalecast.SeriesTransformer import SeriesTransformer
@@ -411,16 +408,16 @@ class SeriesTransformer:
         return self.Transform(func, mean=self.orig_mean, std=self.orig_std)
 
     def ScaleRevert(self, **kwargs):
-        """ reverts the y attribute in the Forecaster object, along with all model results.
-        assumes the scale transformation has been called on the object at some point.
-        reversion function: array.std()*array[i]+array.mean().
+        """ Reverts the y attribute in the Forecaster object, along with all model results.
+        Assumes the scale transformation has been called on the object at some point.
+        Revert function: array.std()*array[i]+array.mean().
 
         Args:
-            **kwargs: passed to Transformer.Revert() - 
+            **kwargs: Passed to Transformer.Revert() - 
                 args `full` and `exclude_models` accepted here.
 
         Returns:
-            (Forecaster): a Forecaster object with the reverted attributes.
+            (Forecaster): A Forecaster object with the reverted attributes.
 
         >>> from scalecast.Forecaster import Forecaster
         >>> from scalecast.SeriesTransformer import SeriesTransformer
@@ -443,14 +440,14 @@ class SeriesTransformer:
             raise ValueError("cannot revert a series that was never scaled.")
 
     def MinMaxTransform(self,train_only=False):
-        """ transforms the y attribute in the Forecaster object using a min-max scale transformation.
-        min-max scale defined as (array[i] - array.min()) / (array.max() - array.min()).
+        """ Transforms the y attribute in the Forecaster object using a min-max scale transformation.
+        Min-max scale defined as (array[i] - array.min()) / (array.max() - array.min()).
 
         Args:
-            train_only (bool): default False.
-                whether to fit the minmax transformer on the training set only.
+            train_only (bool): Default False.
+                Whether to fit the minmax transformer on the training set only.
         Returns:
-            (Forecaster): a Forecaster object with the transformed attributes.
+            (Forecaster): A Forecaster object with the transformed attributes.
 
         >>> from scalecast.Forecaster import Forecaster
         >>> from scalecast.SeriesTransformer import SeriesTransformer
@@ -472,16 +469,16 @@ class SeriesTransformer:
         return self.Transform(func, amin=self.orig_min, amax=self.orig_max,)
 
     def MinMaxRevert(self, **kwargs):
-        """ reverts the y attribute in the Forecaster object, along with all model results.
-        assumes the min-max scale transformation has been called on the object at some point.
-        reversion function: array[i]*(array.max() - array.min()) + array.min().
+        """ Reverts the y attribute in the Forecaster object, along with all model results.
+        Assumes the min-max scale transformation has been called on the object at some point.
+        Revert function: array[i]*(array.max() - array.min()) + array.min().
 
         Args:
-            **kwargs: passed to Transformer.Revert() - 
+            **kwargs: {assed to Transformer.Revert() - 
                 args `full` and `exclude_models` accepted here.
 
         Returns:
-            (Forecaster): a Forecaster object with the reverted attributes.
+            (Forecaster): A Forecaster object with the reverted attributes.
 
         >>> from scalecast.Forecaster import Forecaster
         >>> from scalecast.SeriesTransformer import SeriesTransformer
@@ -505,20 +502,20 @@ class SeriesTransformer:
 
     def DiffTransform(self, m=1):
         """ takes differences or seasonal differences in the Forecaster object's y attribute.
-        if using this transformation, call `Forecaster.add_diffed_terms()` and 
+        If using this transformation, call `Forecaster.add_diffed_terms()` and 
         `Forecaster.add_lagged_terms()` if you want to use those before calling this function.
-        call `Forecaster.add_ar_terms()` and `Forecaster.add_AR_terms()` after calling this function.
-        call twice with the same value of m to take second differences.
-        if using this to take series differences, do not also use the native `Forecaster.diff()` function.
+        Call `Forecaster.add_ar_terms()` and `Forecaster.add_AR_terms()` after calling this function.
+        Call twice with the same value of m to take second differences.
+        iI using this to take series differences, do not also use the native `Forecaster.diff()` function.
 
         Args:
-            m (int): default 1. the seasonal difference to take.
+            m (int): Default 1. The seasonal difference to take.
                 1 will difference once. 
                 12 will take a seasonal difference assuming 12 periods makes a season (monthly data).
-                any int available.
+                Any int available.
 
         Returns:
-            (Forecaster): a Forecaster object with the transformed attributes.
+            (Forecaster): A Forecaster object with the transformed attributes.
 
         >>> from scalecast.Forecaster import Forecaster
         >>> from scalecast.SeriesTransformer import SeriesTransformer
@@ -549,20 +546,20 @@ class SeriesTransformer:
         return f
 
     def DiffRevert(self, m=1, exclude_models = []):
-        """ reverts the y attribute in the Forecaster object, along with all model results.
-        calling this makes so that AR values become unusable and have to be re-added to the object.
-        unlike other revert functions, there is no option for full = False. 
-        if using this to revert differences, you should not also use the native Forecaster.diff() function.
+        """ Reverts the y attribute in the Forecaster object, along with all model results.
+        Calling this makes so that AR values become unusable and have to be re-added to the object.
+        Unlike other revert functions, there is no option for full = False. 
+        If using this to revert differences, you should not also use the native Forecaster.diff() function.
 
         Args:
-            m (int): default 1. the seasonal difference to revert.
+            m (int): Default 1. The seasonal difference to revert.
                 1 will undifference once. 
                 12 will undifference seasonally 12 periods (monthly data).
-                any int available. use the same values to revert as you used
+                Any int available. use the same values to revert as you used
                 to transform the object originally.
 
         Returns:
-            (Forecaster): a Forecaster object with the reverted attributes.
+            (Forecaster): A Forecaster object with the reverted attributes.
 
         >>> from scalecast.Forecaster import Forecaster
         >>> from scalecast.SeriesTransformer import SeriesTransformer
@@ -617,7 +614,6 @@ class SeriesTransformer:
                 seasrevert(h['FittedVals'],self.f.y.values[-len(h['FittedVals'])-m:], m)
             )[m:]
             h['LevelFittedVals'] = h['FittedVals'][:]
-            #ci_range = self.f._find_cis(self.f.y.values[-len(h['FittedVals']):],h['FittedVals'])
             for k in ("LevelUpperCI","UpperCI","LevelLowerCI","LowerCI"):
                 h[k] = list(seasrevert(h[k], self.f.y[-m:], m))[m:]
             for k in ("TestSetUpperCI","LevelTSUpperCI","TestSetLowerCI","LevelTSLowerCI"):
@@ -631,4 +627,4 @@ class SeriesTransformer:
         delattr(self, f"orig_y_{m}_{n}")
         delattr(self, f"orig_dates_{m}_{n}")
 
-        return self.Revert(lambda x: x, exclude_models = exclude_models)  # call here to assign correct test-set metrics
+        return self.Revert(lambda x: x, exclude_models = exclude_models)  # call here to assign correct test-set metrics
\ No newline at end of file
